package domain

type RtaReportTaskTopDTO struct {
	/*
	   报表任务参数
	*/
	Params *ReportTaskParamTopDTO `json:"params,omitempty" required:"true"`

	/*
	   广告主id
	*/
	AdvertiserId *int64 `json:"advertiser_id,omitempty" required:"true"`

	/*
	   任务名称
	*/
	Name *string `json:"name,omitempty" required:"true"`

	/*
	   强制生成新的任务，参数相同会复用之前的任务，1：是，0：否
	*/
	Force *int `json:"force" required:"false"`

	/*
	   平台版本，9999：升级版API（仅巨量2.0API需传入）
	*/
	Version *int `json:"version" required:"false"`
}

func (s *RtaReportTaskTopDTO) SetParams(v ReportTaskParamTopDTO) *RtaReportTaskTopDTO {
	s.Params = &v
	return s
}

func (s *RtaReportTaskTopDTO) SetAdvertiserId(v int64) *RtaReportTaskTopDTO {
	s.AdvertiserId = &v
	return s
}

func (s *RtaReportTaskTopDTO) SetName(v string) *RtaReportTaskTopDTO {
	s.Name = &v
	return s
}

func (s *RtaReportTaskTopDTO) SetForce(v int) *RtaReportTaskTopDTO {
	s.Force = &v
	return s
}

func (s *RtaReportTaskTopDTO) SetVersion(v int) *RtaReportTaskTopDTO {
	s.Version = &v
	return s
}

type ReportTaskParamTopDTO struct {
	/*
	   排序字段
	*/
	OrderByField *string `json:"order_by_field" required:"false"`

	/*
		结束日期, 格式yyyy-MM-dd，按天分组时间区间不能超过一个月，按小时分组只支持查询当天数据
	*/
	EndDate *string `json:"end_date,omitempty" required:"true"`

	/*
	   排序方式，ASC：正序、DESC：倒序
	*/
	OrderByType *string `json:"order_by_type" required:"false"`

	/*
	   分组条件，素材分组仅头条2.0支持，STAT_GROUP_BY_ADVERTISER_ID：按照广告主分组，STAT_GROUP_BY_CAMPAIGN_ID：按照计划组分组，STAT_GROUP_BY_ADGROUP_ID：按照计划分组，STAT_GROUP_BY_CREATIVE_ID：按照创意分组，STAT_GROUP_BY_TIME_DAY：按照天分组，STAT_GROUP_BY_TIME_HOUR：按照小时分组，STAT_GROUP_BY_MATERIAL_ID：按照素材分组，STAT_GROUP_BY_MATERIAL_X_ADGROUP_ID：按照素材X计划分组，STAT_GROUP_BY_COMBINATION_MATERIAL_ID：按照素材组合分组，STAT_GROUP_BY_COMBINATION_MATERIALX_CAMPAIGN_ID：按照素材组合X项目分组
	*/
	GroupBy *[]string `json:"group_by,omitempty" required:"true"`

	/*
	   需要返回的指标，不指定则返回默认指标。具体字段名称参考日报表、小时报表数据查询接口
	*/
	Fields *[]string `json:"fields" required:"false"`

	/*
	   过滤条件
	*/
	Filtering *ReportTaskFilterTopDTO `json:"filtering" required:"false"`

	/*
	   开始日期, 格式yyyy-MM-dd
	*/
	StartDate *string `json:"start_date,omitempty" required:"true"`
}

func (s *ReportTaskParamTopDTO) SetOrderByField(v string) *ReportTaskParamTopDTO {
	s.OrderByField = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetEndDate(v string) *ReportTaskParamTopDTO {
	s.EndDate = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetOrderByType(v string) *ReportTaskParamTopDTO {
	s.OrderByType = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetGroupBy(v []string) *ReportTaskParamTopDTO {
	s.GroupBy = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetFields(v []string) *ReportTaskParamTopDTO {
	s.Fields = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetFiltering(v ReportTaskFilterTopDTO) *ReportTaskParamTopDTO {
	s.Filtering = &v
	return s
}

func (s *ReportTaskParamTopDTO) SetStartDate(v string) *ReportTaskParamTopDTO {
	s.StartDate = &v
	return s
}

type ReportTaskFilterTopDTO struct {
	/*
	   按照计划过滤
	*/
	AdgroupIds *[]int64 `json:"adgroup_ids" required:"false"`

	/*
	   转化效果周期，7：7天，15：15天
	*/
	Effect *int `json:"effect" required:"false"`

	/*
		按照计划组过滤
	*/
	CampaignIds *[]int64 `json:"campaign_ids" required:"false"`

	/*
		按照创意过滤
	*/
	CreativeIds *[]int64 `json:"creative_ids" required:"false"`

	/*
		归因逻辑，1：点击效果，0：展示效果
	*/
	EffectType *int `json:"effect_type" required:"false"`

	/*
	   按照素材过滤，素材id从adgroup查询接口获取，素材组合报表只支持根据标题素材id筛选
	*/
	MaterialId *int64 `json:"material_id" required:"false"`
}
